@@ -1,29 +1,29 @@
 #' Plotting method for \code{survFitTT} objects
 #'
 #' This is the generic \code{plot} S3 method for the \code{survFitTT} class. It
-#' plots exposure-response fits for target time survival analysis.
+#' plots concentration-response fit under target time survival analysis.
 #'
-#' The fitted curve represents the \strong{estimated survival rate} after
-#' the target time has passed as a function of the concentration of pollutant;
+#' The fitted curve represents the \strong{estimated survival rate} at
+#' the target time as a function of the concentration of chemical compound;
 #' When \code{adddata = TRUE} the black dots depict the \strong{observed survival
 #' rate} at each tested concentration. Note that since our model does not take
 #' inter-replicate variability into consideration, replicates are systematically
 #' pooled in this plot.
-#' The function plots both 95 \% credible intervals for the estimated survival
-#' rate (by default the red area around the fitted curve) and 95 \% confidence
-#' intervals for the observed survival rate (as black error bars if
+#' The function plots both 95\% credible intervals for the estimated survival
+#' rate (by default the grey area around the fitted curve) and 95\% binomial confidence
+#' intervals for the observed survival rate (as black segments if
 #' \code{adddata = TRUE}).
 #' Both types of intervals are taken at the same level. Typically
 #' a good fit is expected to display a large overlap between the two intervals.
 #' If spaghetti = TRUE, the credible intervals are represented by two dotted
 #' lines limiting the credible band, and a spaghetti plot is added to this band.
-#' It consists of the representation of simulated curves using parameter values
-#' sampled in the posterior distribution (10 \% of the MCMC chains are randomly
+#' This spaghetti plot consists of the representation of simulated curves using parameter values
+#' sampled in the posterior distribution (10\% of the MCMC chains are randomly
 #' taken for this sample).
 #'
 #' @param x an object of class \code{survFitTT}
-#' @param xlab a title for the \eqn{x}-axis
-#' @param ylab a title for the \eqn{y}-axis
+#' @param xlab a label for the \eqn{X}-axis, default is \code{Concentration}
+#' @param ylab a label for the \eqn{Y}-axis, default is \code{Survival rate}
 #' @param main main title for the plot
 #' @param fitcol color of the fitted curve
 #' @param fitlty line type of the fitted curve
@@ -33,10 +33,12 @@
 #' @param cicol color of the 95 \% credible interval limits
 #' @param cilty line type for the 95 \% credible interval limits
 #' @param cilwd width of the 95 \% credible interval limits
-#' @param adddata if \code{TRUE}, adds the observed data with confidence interval
+#' @param ribcol color of the ribbon between lower and upper credible limits.
+#' Transparent if \code{NULL}
+#' @param adddata if \code{TRUE}, adds the observed data with confidence intervals
 #' to the plot
 #' @param addlegend if \code{TRUE}, adds a default legend to the plot
-#' @param log.scale if \code{TRUE}, displays \eqn{x}-axis in log scale
+#' @param log.scale if \code{TRUE}, displays \eqn{X}-axis in log-scale
 #' @param style graphical backend, can be \code{'generic'} or \code{'ggplot'}
 #' @param \dots Further arguments to be passed to generic methods
 #' @note When \code{style = "ggplot"}, the function calls function
@@ -80,17 +82,18 @@ plot.survFitTT <- function(x,
                            xlab = "Concentration",
                            ylab = "Survival rate",
                            main = NULL,
-                           fitcol = "red",
+                           fitcol = "orange",
                            fitlty = 1,
                            fitlwd = 1,
                            spaghetti = FALSE,
-                           cicol = "pink1",
-                           cilty = 1,
+                           cicol = "orange",
+                           cilty = 2,
                            cilwd = 1,
+                           ribcol = "grey70",
                            adddata = FALSE,
                            addlegend = FALSE,
                            log.scale = FALSE,
-                           style = "generic", ...) {
+                           style = "ggplot", ...) {
   # plot the fitted curve estimated by survFitTT
   # INPUTS
   # - x:  survFitTt object
@@ -145,7 +148,7 @@ plot.survFitTT <- function(x,
                               conf.int, cred.int, spaghetti.CI, dataCIm,
                               xlab, ylab, fitcol, fitlty, fitlwd,
                               main, addlegend, adddata,
-                              cicol, cilty, cilwd, log.scale)
+                              cicol, cilty, cilwd, ribcol, log.scale)
   }
   else if (style == "ggplot") {
     survFitPlotGG(x,
@@ -154,7 +157,7 @@ plot.survFitTT <- function(x,
                   conf.int, cred.int, spaghetti.CI, dataCIm,
                   xlab, ylab, fitcol, fitlty, fitlwd,
                   main, addlegend, adddata,
-                  cicol, cilty, cilwd / 2)
+                  cicol, cilty, cilwd / 2, ribcol)
   }
   else stop("Unknown style")
 }
@@ -270,7 +273,7 @@ survFitPlotGenericCredInt <- function(x,
                                       conf.int, cred.int, spaghetti.CI, dataCIm,
                                       xlab, ylab, fitcol, fitlty, fitlwd,
                                       main, addlegend, adddata,
-                                      cicol, cilty, cilwd, log.scale)
+                                      cicol, cilty, cilwd, ribcol, log.scale)
 {
   # plot the fitted curve estimated by survFitTT
   # with generic style with credible interval
@@ -298,10 +301,10 @@ survFitPlotGenericCredInt <- function(x,
     by(dataCIm, dataCIm$variable, function(x) {
       lines(x$curv_conc, x$value, col = color_transparent)
     })
-  } else {
+  } else if(!is.null(ribcol)) {
     polygon(c(curv_conc, rev(curv_conc)), c(cred.int[["qinf95"]],
                                             rev(cred.int[["qsup95"]])),
-            col = cicol, border = NA)
+            col = ribcol, border = NA)
   }
   
   lines(curv_conc, cred.int[["qsup95"]], type = "l", col = cicol, lty = cilty,
@@ -341,7 +344,7 @@ survFitPlotGenericCredInt <- function(x,
 #' @importFrom grid arrow unit
 survFitPlotGGCredInt <- function(x, data, curv_resp, conf.int, cred.int,
                                  spaghetti.CI, dataCIm, cilty, cilwd,
-                                 valCols, fitlty, fitlwd, xlab, ylab, main,
+                                 valCols, fitlty, fitlwd, ribcol, xlab, ylab, main,
                                  adddata) {
   # IC
   data.three <- data.frame(conc = data$transf_conc,
@@ -369,7 +372,7 @@ survFitPlotGGCredInt <- function(x, data, curv_resp, conf.int, cred.int,
   } else {
     ggplot(data) + geom_ribbon(data = data.four, aes(x = conc, ymin = qinf95,
                                                      ymax = qsup95),
-                               fill = valCols$cols4, col = valCols$cols4, alpha = 0.4)
+                               fill = ribcol, col = NA, alpha = 0.4)
   }
   
   plt_32 <- plt_302 +
@@ -390,8 +393,8 @@ survFitPlotGGCredInt <- function(x, data, curv_resp, conf.int, cred.int,
     plt_40 <- ggplot(data) + geom_ribbon(data = data.four, aes(x = conc,
                                                                ymin = qinf95,
                                                                ymax = qsup95),
-                                         fill = valCols$cols4,
-                                         col = valCols$cols4, alpha = 0.4)
+                                         fill = ribcol,
+                                         col = NA, alpha = 0.4)
   }
   
   plt_401 <- plt_40 +
@@ -425,7 +428,7 @@ survFitPlotGG <- function(x,
                           conf.int, cred.int, spaghetti.CI, dataCIm,
                           xlab, ylab, fitcol, fitlty, fitlwd,
                           main, addlegend, adddata,
-                          cicol, cilty, cilwd) {
+                          cicol, cilty, cilwd, ribcol) {
   
   
   if (Sys.getenv("RSTUDIO") == "") {
@@ -457,7 +460,7 @@ survFitPlotGG <- function(x,
   
   plt_4 <-
     survFitPlotGGCredInt(x, data, curv_resp, conf.int, cred.int, spaghetti.CI,
-                         dataCIm, cilty, cilwd, valCols, fitlty, fitlwd,
+                         dataCIm, cilty, cilwd, valCols, fitlty, fitlwd, ribcol,
                          xlab, ylab, main, adddata)$plt_4
   
   if (addlegend) { # legend yes
@@ -470,11 +473,11 @@ survFitPlotGG <- function(x,
     
     plt_3 <- survFitPlotGGCredInt(x, data, curv_resp, conf.int, cred.int, 
                                   spaghetti.CI, dataCIm, cilty, cilwd,
-                                  valCols, fitlty, fitlwd, xlab, ylab, main,
+                                  valCols, fitlty, fitlwd, ribcol, xlab, ylab, main,
                                   adddata)$plt_3
     plt_32 <- survFitPlotGGCredInt(x, data, curv_resp, conf.int, cred.int, 
                                    spaghetti.CI, dataCIm, cilty, cilwd,
-                                   valCols, fitlty, fitlwd, xlab, ylab, main,
+                                   valCols, fitlty, fitlwd, ribcol, xlab, ylab, main,
                                    adddata)$plt_32
     
     mylegend_3 <- if (adddata) { legendGgplotFit(plt_3) } else NULL
